# Generated by Django 4.2.16 on 2026-02-27 11:46

# Django
import django.db.models.deletion
from django.db import migrations, models

# AA Example App
import corptools.models.skills


class Migration(migrations.Migration):

    replaces = [
        ('corptools', '0001_initial'),
        ('corptools', '0002_auto_20200507_1104'),
        ('corptools', '0003_auto_20200507_1115'),
        ('corptools', '0004_auto_20200507_1133'),
        ('corptools', '0005_auto_20200508_1506'),
        ('corptools', '0006_invtypematerials_type_id'),
        ('corptools', '0007_auto_20200510_1357'),
        ('corptools', '0008_auto_20200511_0801'),
        ('corptools', '0009_auto_20200511_0816'),
        ('corptools', '0010_auto_20200511_0853'),
        ('corptools', '0011_characterwalletjournalentry_corporationwalletdivision_corporationwalletjournalentry'),
        ('corptools', '0012_skilltotals'),
        ('corptools', '0013_eveitemdogmaattribute'),
        ('corptools', '0014_characteraudit_balance'),
        ('corptools', '0015_auto_20200614_0935'),
        ('corptools', '0016_auto_20200622_0643'),
        ('corptools', '0017_auto_20200727_0041'),
        ('corptools', '0018_corporationwalletdivision_name'),
        ('corptools', '0019_implant_jumpclone'),
        ('corptools', '0020_clone'),
        ('corptools', '0021_auto_20200804_0941'),
        ('corptools', '0022_mapsystemgate_skilllist'),
        ('corptools', '0023_auto_20200810_1350'),
        ('corptools', '0024_auto_20200810_1458'),
        ('corptools', '0025_mapjumpbridge'),
        ('corptools', '0026_auto_20200811_0846'),
        ('corptools', '0027_skilllistfile'),
        ('corptools', '0028_delete_skilllistfile'),
        ('corptools', '0029_auto_20200815_0554'),
        ('corptools', '0030_charactermarketorder_corporationmarketorder'),
        ('corptools', '0031_auto_20200828_0855'),
        ('corptools', '0032_auto_20200901_0537'),
        ('corptools', '0033_skilllist_order_weight'),
        ('corptools', '0034_auto_20200928_0005'),
        ('corptools', '0035_auto_20200929_0114'),
        ('corptools', '0036_auto_20201017_0641'),
        ('corptools', '0037_mapsystemmoon_mapsystemplanet'),
        ('corptools', '0038_auto_20210112_0102'),
        ('corptools', '0039_auto_20210112_0402'),
        ('corptools', '0040_auto_20210112_0449'),
        ('corptools', '0041_auto_20210112_1359'),
        ('corptools', '0042_remove_skilllist_eft'),
        ('corptools', '0043_auto_20210125_0758'),
        ('corptools', '0044_auto_20210322_0805'),
        ('corptools', '0045_bigkey_assets_fix'),
        ('corptools', '0046_auto_20210427_0734'),
        ('corptools', '0047_auto_20210531_1025'),
        ('corptools', '0048_maillabel_mailmessage_mailrecipient'),
        ('corptools', '0049_alter_mailmessage_is_read'),
        ('corptools', '0050_auto_20210713_0408'),
        ('corptools', '0051_auto_20210713_0557'),
        ('corptools', '0052_charactercontact_charactercontactlabel_corporationcontact_corporationcontactlabel'),
        ('corptools', '0053_characteraudit_last_update_contacts'),
        ('corptools', '0054_auto_20210808_0138'),
        ('corptools', '0055_alter_characterroles_character'),
        ('corptools', '0056_auto_20210808_0414'),
        ('corptools', '0057_alter_titlefilter_options'),
        ('corptools', '0058_auto_20210808_0635'),
        ('corptools', '0059_invtypematerials_met_type'),
        ('corptools', '0060_bridgeozonelevel'),
        ('corptools', '0061_notificationtext'),
        ('corptools', '0062_notificaiton_refactor'),
        ('corptools', '0063_notification_verification'),
        ('corptools', '0064_notification_note_text'),
        ('corptools', '0065_notification_sync'),
        ('corptools', '0066_final_notification_checks'),
        ('corptools', '0067_remove_notification_notification_text'),
        ('corptools', '0068_rename_note_text_notification_notification_text'),
        ('corptools', '0069_corptoolsconfiguration'),
        ('corptools', '0070_create_settings'),
        ('corptools', '0071_alter_corptoolsconfiguration_options'),
        ('corptools', '0072_alter_corporationaudit_options'),
        ('corptools', '0073_remove_miningtaxpaymentcorp_corp_delete_miningtax_and_more'),
        ('corptools', '0074_evelocation_managed_evelocation_managed_char_and_more'),
        ('corptools', '0075_remove_notification_corptools_n_notific_77c7f2_idx'),
        ('corptools', '0076_remove_characterasset_corptools_c_type_id_05ccc2_idx_and_more'),
        ('corptools', '0077_fullyloadedfilter_reversed_logic'),
        ('corptools', '0078_characterwalletjournalentry_corptools_c_date_aebcea_idx_and_more'),
        ('corptools', '0079_characteraudit_last_update_location_and_more'),
        ('corptools', '0080_alter_characterlocation_character'),
        ('corptools', '0081_characterlocation_current_ship_name_and_more'),
        ('corptools', '0082_characteraudit_last_update_contracts_contract_and_more'),
        ('corptools', '0083_skilltotalhistory'),
        ('corptools', '0084_characteraudit_last_update_loyaltypoints_and_more'),
        ('corptools', '0085_characteraudit_last_update_mining_and_more'),
        ('corptools', '0086_characterindustryjob'),
        ('corptools', '0087_characteraudit_last_update_indy'),
        ('corptools', '0088_alter_characterindustryjob_end_date'),
        ('corptools', '0089_highestspfilter'),
        ('corptools', '0090_rename_cache_expire_assets_corporationaudit_last_change_assets_and_more'),
        ('corptools', '0091_assetsfilter_count_message_only_and_more'),
        ('corptools', '0092_poco'),
        ('corptools', '0093_alter_characteraudit_options'),
        ('corptools', '0094_lastloginfilter_characteraudit_last_known_login_and_more'),
        ('corptools', '0095_lastloginfilter_main_corp_only_and_more'),
        ('corptools', '0096_rolefilter_main_only'),
        ('corptools', '0097_rolefilter_alliances_filter_rolefilter_corps_filter'),
        ('corptools', '0098_migrate_role_filters'),
        ('corptools', '0099_remove_rolefilter_alliance_filter_and_more'),
        ('corptools', '0100_mapjumpbridge_manually_input'),
        ('corptools', '0101_corporatecontract_corporatecontractitem'),
        ('corptools', '0102_corporationaudit_last_change_contracts_and_more'),
        ('corptools', '0103_currentshipfilter'),
        ('corptools', '0104_remove_currentshipfilter_categories_and_more'),
        ('corptools', '0105_homestationfilter'),
        ('corptools', '0106_remove_homestationfilter_constellations_and_more'),
        ('corptools', '0107_rename_structures_homestationfilter_evelocation'),
        ('corptools', '0108_jumpclonefilter'),
        ('corptools', '0109_corptoolsconfiguration_disable_verification_assets_and_more'),
        ('corptools', '0110_rename_oreprice_typeprice'),
        ('corptools', '0111_corptoolsconfiguration_disable_update_assets_and_more'),
        ('corptools', '0112_alter_corptoolsconfiguration_holding_corps'),
        ('corptools', '0113_timeincorpfilter_reversed_logic'),
        ('corptools', '0114_alter_skilllist_skill_list'),
        ('corptools', '0115_assetcoordiante'),
        ('corptools', '0116_starbase'),
        ('corptools', '0117_starbase_name'),
        ('corptools', '0118_alter_skill_id'),
        ('corptools', '0119_characteragefilter'),
        ('corptools', '0120_corptoolsconfiguration_aggregate_lookback'),
        ('corptools', '0121_charassetcoordiante'),
        ('corptools', '0122_characteraudit_total_logins'),
        ('corptools', '0123_characterwalletjournalentry_processed_and_more'),
        ('corptools', '0124_characterbountyevent_characterbountystat'),
        ('corptools', '0125_corporationaudit_last_change_industry_jobs_and_more'),
        ('corptools', '0126_assetsfilter_reversed_logic'),
        ('corptools', '0127_alter_corporationaudit_options'),
        ('corptools', '0128_clear_skill_cache'),
        ('corptools', '0129_alter_notification_id'),
        ('corptools', '0130_swap_to_eve_sde')
    ]

    initial = True

    dependencies = [
        ("eve_sde", "0012_alter_constellation_region"),
        ("eveonline", "0017_alliance_and_corp_names_are_not_unique"),
    ]

    operations = [
        migrations.CreateModel(
            name="BridgeOzoneLevel",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                ("station_id", models.CharField(max_length=500)),
                ("quantity", models.BigIntegerField()),
                ("used", models.BigIntegerField(default=0)),
                ("date", models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name="CharacterAgeFilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                ("min_age", models.IntegerField(default=30)),
                (
                    "reversed_logic",
                    models.BooleanField(
                        default=False,
                        help_text="If set all user with age less than the min_max_age will pass the test.",
                    ),
                ),
            ],
            options={
                "verbose_name": "Smart Filter: Character Age Filter",
                "verbose_name_plural": "Smart Filter: Character Age Filter",
            },
        ),
        migrations.CreateModel(
            name="CharacterAsset",
            fields=[
                ("id", models.BigAutoField(primary_key=True, serialize=False)),
                ("blueprint_copy", models.BooleanField(default=None, null=True)),
                ("singleton", models.BooleanField()),
                ("item_id", models.BigIntegerField()),
                ("location_flag", models.CharField(max_length=50)),
                ("location_id", models.BigIntegerField()),
                ("location_type", models.CharField(max_length=25)),
                ("quantity", models.IntegerField()),
                ("type_id", models.IntegerField()),
                ("name", models.CharField(default=None, max_length=255, null=True)),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="CharacterAudit",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("active", models.BooleanField(default=False)),
                (
                    "last_update_pub_data",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_skills",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_skill_que",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_clones",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_contacts",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_contracts",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_assets",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_wallet",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_orders",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_notif",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_roles",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_titles",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_mails",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_location",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_loyaltypoints",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_mining",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_indy",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_login",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "balance",
                    models.DecimalField(
                        decimal_places=2, default=None, max_digits=20, null=True
                    ),
                ),
                (
                    "last_known_login",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_known_logoff",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "total_logins",
                    models.IntegerField(blank=True, default=None, null=True),
                ),
                (
                    "character",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eveonline.evecharacter",
                    ),
                ),
            ],
            options={
                "permissions": (
                    ("corp_hr", "Can access other character's data for own corp."),
                    (
                        "alliance_hr",
                        "Can access other character's data for own alliance.",
                    ),
                    ("state_hr", "Can access other character's data for own state."),
                    ("guest_hr", "Can access guest users's data for HR purposes."),
                    (
                        "global_hr",
                        "Can access other character's data for characters in any corp/alliance/state.",
                    ),
                ),
            },
        ),
        migrations.CreateModel(
            name="CharacterBountyEvent",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("message", models.TextField()),
            ],
        ),
        migrations.CreateModel(
            name="CharacterTitle",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("title_id", models.IntegerField()),
                ("title", models.CharField(max_length=500)),
                ("corporation_id", models.BigIntegerField()),
                ("corporation_name", models.CharField(max_length=500)),
            ],
        ),
        migrations.CreateModel(
            name="Contract",
            fields=[
                (
                    "id",
                    models.CharField(
                        max_length=50, primary_key=True, serialize=False),
                ),
                ("contract_id", models.IntegerField()),
                ("acceptor_id", models.IntegerField()),
                ("assignee_id", models.IntegerField()),
                ("issuer_id", models.IntegerField()),
                ("issuer_corporation_id", models.IntegerField()),
                (
                    "collateral",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=20, null=True
                    ),
                ),
                (
                    "buyout",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=20, null=True
                    ),
                ),
                (
                    "price",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=20, null=True
                    ),
                ),
                (
                    "reward",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=20, null=True
                    ),
                ),
                (
                    "volume",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=20, null=True
                    ),
                ),
                ("days_to_complete", models.IntegerField(blank=True, null=True)),
                ("start_location_id", models.BigIntegerField(blank=True, null=True)),
                ("end_location_id", models.BigIntegerField(blank=True, null=True)),
                ("for_corporation", models.BooleanField()),
                ("date_accepted", models.DateTimeField(blank=True, null=True)),
                ("date_completed", models.DateTimeField(blank=True, null=True)),
                ("date_expired", models.DateTimeField()),
                ("date_issued", models.DateTimeField()),
                ("status", models.CharField(max_length=25)),
                ("contract_type", models.CharField(max_length=20)),
                ("availability", models.CharField(max_length=15)),
                ("title", models.CharField(max_length=256)),
            ],
        ),
        migrations.CreateModel(
            name="CorpAsset",
            fields=[
                ("id", models.BigAutoField(primary_key=True, serialize=False)),
                ("blueprint_copy", models.BooleanField(default=None, null=True)),
                ("singleton", models.BooleanField()),
                ("item_id", models.BigIntegerField()),
                ("location_flag", models.CharField(max_length=50)),
                ("location_id", models.BigIntegerField()),
                ("location_type", models.CharField(max_length=25)),
                ("quantity", models.IntegerField()),
                ("type_id", models.IntegerField()),
                ("name", models.CharField(default=None, max_length=255, null=True)),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="CorporationAudit",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "last_update_pub_data",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_change_pub_data",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_assets",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_change_assets",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_structures",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_change_structures",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_moons",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_change_moons",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_observers",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_change_observers",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_wallet",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_change_wallet",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_contracts",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_change_contracts",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_industry_jobs",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_change_industry_jobs",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "last_update_known_login",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "corporation",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eveonline.evecorporationinfo",
                    ),
                ),
            ],
            options={
                "permissions": (
                    ("own_corp_manager", "Can access own corporations's data."),
                    (
                        "alliance_corp_manager",
                        "Can access other corporations's data for own alliance.",
                    ),
                    (
                        "state_corp_manager",
                        "Can access other corporations's data for own state.",
                    ),
                    ("global_corp_manager", "Can access all corporations's data."),
                    (
                        "show_if_director",
                        "Can access all corporations's where character is a director.",
                    ),
                ),
            },
        ),
        migrations.CreateModel(
            name="CorporationWalletDivision",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(default=None, max_length=100, null=True)),
                ("balance", models.DecimalField(decimal_places=2, max_digits=20)),
                ("division", models.IntegerField()),
                (
                    "corporation",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="corporation_division",
                        to="corptools.corporationaudit",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="EveItemCategory",
            fields=[
                (
                    "category_id",
                    models.BigIntegerField(primary_key=True, serialize=False),
                ),
                ("name", models.CharField(max_length=255)),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="EveItemGroup",
            fields=[
                ("group_id", models.BigIntegerField(
                    primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=255)),
                (
                    "category",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.eveitemcategory",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="EveItemType",
            fields=[
                ("type_id", models.BigIntegerField(
                    primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=255)),
                ("description", models.TextField(default=None, null=True)),
                ("mass", models.FloatField(default=None, null=True)),
                ("packaged_volume", models.FloatField(default=None, null=True)),
                ("portion_size", models.FloatField(default=None, null=True)),
                ("volume", models.FloatField(default=None, null=True)),
                ("published", models.BooleanField()),
                ("radius", models.FloatField(default=None, null=True)),
                (
                    "group",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.eveitemgroup",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="EveLocation",
            fields=[
                (
                    "location_id",
                    models.BigIntegerField(primary_key=True, serialize=False),
                ),
                ("location_name", models.CharField(max_length=255)),
                ("last_update", models.DateTimeField(auto_now=True)),
                ("managed", models.BooleanField(default=False)),
                (
                    "managed_char",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "managed_corp",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.corporationaudit",
                    ),
                ),
                (
                    "system",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="eve_sde.solarsystem",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="EveName",
            fields=[
                ("eve_id", models.BigIntegerField(
                    primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=255)),
                ("category", models.CharField(max_length=50)),
                ("last_update", models.DateTimeField(auto_now=True)),
                (
                    "alliance",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="alli",
                        to="corptools.evename",
                    ),
                ),
                (
                    "corporation",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="corp",
                        to="corptools.evename",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="FullyLoadedFilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                (
                    "reversed_logic",
                    models.BooleanField(
                        default=False,
                        help_text="If set all members WITHOUT audit fully loaded will pass the test.",
                    ),
                ),
                ("count_message_only", models.BooleanField(default=False)),
            ],
            options={
                "verbose_name": "Smart Filter: Audit Fully Loaded",
                "verbose_name_plural": "Smart Filter: Audit Fully Loaded",
            },
        ),
        migrations.CreateModel(
            name="HighestSPFilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                ("sp_cutoff", models.BigIntegerField(default=5000000000)),
                ("swap_logic", models.BooleanField(default=False)),
            ],
            options={
                "verbose_name": "Smart Filter: Highest SP Character",
                "verbose_name_plural": "Smart Filter: Highest SP Character",
            },
        ),
        migrations.CreateModel(
            name="LastLoginfilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                (
                    "days_since_login",
                    models.IntegerField(
                        default=30,
                        help_text="Days since last login of any Character in the accounts before failing the filter.",
                    ),
                ),
                (
                    "no_data_pass",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="If there is no data (No Valid Corp Token) for a characters account then should this filter automatically pass.",
                    ),
                ),
                (
                    "main_corp_only",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Only check characters in main's corporation.",
                    ),
                ),
            ],
            options={
                "verbose_name": "Smart Filter: Last Login Check",
                "verbose_name_plural": "Smart Filter: Last Login Check",
            },
        ),
        migrations.CreateModel(
            name="MailLabel",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("label_id", models.IntegerField(default=None)),
                (
                    "label_name",
                    models.CharField(default=None, max_length=255, null=True),
                ),
                (
                    "label_color",
                    models.CharField(default=None, max_length=7, null=True),
                ),
                ("unread_count", models.IntegerField(default=None, null=True)),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="MapConstellation",
            fields=[
                (
                    "constellation_id",
                    models.BigIntegerField(primary_key=True, serialize=False),
                ),
                ("name", models.CharField(max_length=255)),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="MapRegion",
            fields=[
                (
                    "region_id",
                    models.BigIntegerField(primary_key=True, serialize=False),
                ),
                ("name", models.CharField(max_length=255)),
                ("description", models.TextField(default=None, null=True)),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="MapSystem",
            fields=[
                (
                    "system_id",
                    models.BigIntegerField(primary_key=True, serialize=False),
                ),
                ("security_status", models.FloatField()),
                ("name", models.CharField(max_length=255)),
                ("x", models.FloatField()),
                ("y", models.FloatField()),
                ("z", models.FloatField()),
                (
                    "security_class",
                    models.CharField(default=None, max_length=255, null=True),
                ),
                ("star_id", models.IntegerField(default=None, null=True)),
                (
                    "constellation",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.mapconstellation",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="NotificationText",
            fields=[
                (
                    "notification_id",
                    models.BigIntegerField(primary_key=True, serialize=False),
                ),
                ("notification_text", models.TextField(default=None, null=True)),
            ],
        ),
        migrations.CreateModel(
            name="OreTaxRates",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tag", models.CharField(default="Mining Tax", max_length=500)),
                (
                    "refine_rate",
                    models.DecimalField(
                        decimal_places=2, default=87.5, max_digits=5),
                ),
                ("ore_rate", models.DecimalField(decimal_places=2, max_digits=5)),
                (
                    "ubiquitous_rate",
                    models.DecimalField(decimal_places=2, max_digits=5),
                ),
                ("common_rate", models.DecimalField(
                    decimal_places=2, max_digits=5)),
                ("uncommon_rate", models.DecimalField(
                    decimal_places=2, max_digits=5)),
                ("rare_rate", models.DecimalField(decimal_places=2, max_digits=5)),
                (
                    "excptional_rate",
                    models.DecimalField(decimal_places=2, max_digits=5),
                ),
            ],
        ),
        migrations.CreateModel(
            name="SkillList",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_update", models.DateTimeField(auto_now=True)),
                ("name", models.CharField(default=None, max_length=500, null=True)),
                (
                    "skill_list",
                    models.TextField(
                        default="",
                        null=True,
                        validators=[corptools.models.skills.valid_skills],
                    ),
                ),
                ("show_on_audit", models.BooleanField(default=True)),
                ("order_weight", models.IntegerField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name="Structure",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("fuel_expires", models.DateTimeField(default=None, null=True)),
                ("next_reinforce_apply", models.DateTimeField(
                    default=None, null=True)),
                ("next_reinforce_hour", models.IntegerField(default=None, null=True)),
                (
                    "next_reinforce_weekday",
                    models.IntegerField(default=None, null=True),
                ),
                ("profile_id", models.IntegerField()),
                ("reinforce_hour", models.IntegerField()),
                ("reinforce_weekday", models.IntegerField(default=None, null=True)),
                (
                    "state",
                    models.CharField(
                        choices=[
                            ("anchor_vulnerable", "anchor_vulnerable"),
                            ("anchoring", "anchoring"),
                            ("armor_reinforce", "armor_reinforce"),
                            ("armor_vulnerable", "armor_vulnerable"),
                            ("deploy_vulnerable", "deploy_vulnerable"),
                            ("fitting_invulnerable", "fitting_invulnerable"),
                            ("hull_reinforce", "hull_reinforce"),
                            ("hull_vulnerable", "hull_vulnerable"),
                            ("online_deprecated", "online_deprecated"),
                            ("onlining_vulnerable", "onlining_vulnerable"),
                            ("shield_vulnerable", "shield_vulnerable"),
                            ("unanchored", "unanchored"),
                            ("unknown", "unknown"),
                        ],
                        max_length=25,
                    ),
                ),
                ("state_timer_end", models.DateTimeField(default=None, null=True)),
                ("state_timer_start", models.DateTimeField(default=None, null=True)),
                ("structure_id", models.BigIntegerField()),
                ("system_id", models.IntegerField()),
                ("type_id", models.IntegerField()),
                ("unanchors_at", models.DateTimeField(default=None, null=True)),
                ("name", models.CharField(max_length=150)),
                ("last_online_time", models.DateTimeField(default=None, null=True)),
            ],
        ),
        migrations.CreateModel(
            name="StructureCelestial",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("structure_id", models.BigIntegerField()),
                (
                    "celestial_name",
                    models.CharField(default=None, max_length=500, null=True),
                ),
            ],
        ),
        migrations.CreateModel(
            name="TimeInCorpFilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                ("days_in_corp", models.IntegerField(default=30)),
                (
                    "reversed_logic",
                    models.BooleanField(
                        default=False,
                        help_text="If set all members less than the days in corp will pass the test.",
                    ),
                ),
            ],
            options={
                "verbose_name": "Smart Filter: Main's Time in Corp",
                "verbose_name_plural": "Smart Filter: Main's Time in Corp",
            },
        ),
        migrations.CreateModel(
            name="AssetCoordiante",
            fields=[
                (
                    "item",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        primary_key=True,
                        related_name="coordinate",
                        serialize=False,
                        to="corptools.corpasset",
                    ),
                ),
                ("x", models.FloatField()),
                ("y", models.FloatField()),
                ("z", models.FloatField()),
            ],
        ),
        migrations.CreateModel(
            name="CharAssetCoordiante",
            fields=[
                (
                    "item",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        primary_key=True,
                        related_name="coordinate",
                        serialize=False,
                        to="corptools.characterasset",
                    ),
                ),
                ("x", models.FloatField()),
                ("y", models.FloatField()),
                ("z", models.FloatField()),
            ],
        ),
        migrations.CreateModel(
            name="TypePrice",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("price", models.DecimalField(decimal_places=2, max_digits=20)),
                ("last_update", models.DateTimeField(auto_now=True)),
                (
                    "item",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="Titlefilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                (
                    "titles",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.charactertitle",
                    ),
                ),
            ],
            options={
                "verbose_name": "Smart Filter: Corporate Title checks",
                "verbose_name_plural": "Smart Filter: Corporate Title checks",
            },
        ),
        migrations.CreateModel(
            name="StructureService",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=100)),
                (
                    "state",
                    models.CharField(
                        choices=[
                            ("online", "online"),
                            ("offline", "offline"),
                            ("cleanup", "cleanup"),
                        ],
                        max_length=8,
                    ),
                ),
                (
                    "structure",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.structure",
                    ),
                ),
            ],
        ),
        migrations.AddField(
            model_name="structure",
            name="closest_celestial",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="corptools.structurecelestial",
            ),
        ),
        migrations.AddField(
            model_name="structure",
            name="corporation",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="ct_structure",
                to="corptools.corporationaudit",
            ),
        ),
        migrations.AddField(
            model_name="structure",
            name="system_name",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="eve_sde.solarsystem",
            ),
        ),
        migrations.AddField(
            model_name="structure",
            name="type_name",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="eve_sde.itemtype",
            ),
        ),
        migrations.CreateModel(
            name="Starbase",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("starbase_id", models.BigIntegerField()),
                (
                    "name",
                    models.CharField(blank=True, default="",
                                     max_length=255, null=True),
                ),
                ("onlined_since", models.DateTimeField(default=None, null=True)),
                ("reinforced_until", models.DateTimeField(default=None, null=True)),
                ("unanchor_at", models.DateTimeField(default=None, null=True)),
                ("allow_alliance_members", models.BooleanField(default=False)),
                ("allow_corporation_members", models.BooleanField(default=False)),
                ("attack_if_at_war", models.BooleanField(default=False)),
                (
                    "attack_if_other_security_status_dropping",
                    models.BooleanField(default=False),
                ),
                ("use_alliance_standings", models.BooleanField(default=False)),
                (
                    "attack_security_status_threshold",
                    models.FloatField(default=None, null=True),
                ),
                (
                    "attack_standing_threshold",
                    models.FloatField(default=None, null=True),
                ),
                (
                    "state",
                    models.CharField(
                        choices=[
                            ("online", "online"),
                            ("offline", "offline"),
                            ("onlining", "onlining"),
                            ("reinforced", "reinforced"),
                            ("unanchoring", "unanchoring"),
                        ],
                        max_length=12,
                    ),
                ),
                (
                    "anchor",
                    models.CharField(
                        choices=[
                            ("alliance_member", "alliance_member"),
                            (
                                "config_starbase_equipment_role",
                                "config_starbase_equipment_role",
                            ),
                            ("corporation_member", "corporation_member"),
                            (
                                "starbase_fuel_technician_role",
                                "starbase_fuel_technician_role",
                            ),
                        ],
                        default=None,
                        max_length=31,
                        null=True,
                    ),
                ),
                (
                    "online",
                    models.CharField(
                        choices=[
                            ("alliance_member", "alliance_member"),
                            (
                                "config_starbase_equipment_role",
                                "config_starbase_equipment_role",
                            ),
                            ("corporation_member", "corporation_member"),
                            (
                                "starbase_fuel_technician_role",
                                "starbase_fuel_technician_role",
                            ),
                        ],
                        default=None,
                        max_length=31,
                        null=True,
                    ),
                ),
                (
                    "offline",
                    models.CharField(
                        choices=[
                            ("alliance_member", "alliance_member"),
                            (
                                "config_starbase_equipment_role",
                                "config_starbase_equipment_role",
                            ),
                            ("corporation_member", "corporation_member"),
                            (
                                "starbase_fuel_technician_role",
                                "starbase_fuel_technician_role",
                            ),
                        ],
                        default=None,
                        max_length=31,
                        null=True,
                    ),
                ),
                (
                    "unanchor",
                    models.CharField(
                        choices=[
                            ("alliance_member", "alliance_member"),
                            (
                                "config_starbase_equipment_role",
                                "config_starbase_equipment_role",
                            ),
                            ("corporation_member", "corporation_member"),
                            (
                                "starbase_fuel_technician_role",
                                "starbase_fuel_technician_role",
                            ),
                        ],
                        default=None,
                        max_length=31,
                        null=True,
                    ),
                ),
                (
                    "fuel_bay_take",
                    models.CharField(
                        choices=[
                            ("alliance_member", "alliance_member"),
                            (
                                "config_starbase_equipment_role",
                                "config_starbase_equipment_role",
                            ),
                            ("corporation_member", "corporation_member"),
                            (
                                "starbase_fuel_technician_role",
                                "starbase_fuel_technician_role",
                            ),
                        ],
                        default=None,
                        max_length=31,
                        null=True,
                    ),
                ),
                (
                    "fuel_bay_view",
                    models.CharField(
                        choices=[
                            ("alliance_member", "alliance_member"),
                            (
                                "config_starbase_equipment_role",
                                "config_starbase_equipment_role",
                            ),
                            ("corporation_member", "corporation_member"),
                            (
                                "starbase_fuel_technician_role",
                                "starbase_fuel_technician_role",
                            ),
                        ],
                        default=None,
                        max_length=31,
                        null=True,
                    ),
                ),
                ("fuels", models.TextField(blank=True, default="", null=True)),
                (
                    "corporation",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.corporationaudit",
                    ),
                ),
                (
                    "moon",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eve_sde.moon",
                    ),
                ),
                (
                    "system",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eve_sde.solarsystem",
                    ),
                ),
                (
                    "type_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="SkillTotals",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("total_sp", models.BigIntegerField()),
                ("unallocated_sp", models.IntegerField(default=None, null=True)),
                (
                    "character",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="SkillTotalHistory",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("date", models.DateTimeField(auto_now=True)),
                ("total_sp", models.BigIntegerField()),
                ("unallocated_sp", models.IntegerField(default=0)),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="SkillQueue",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("finish_level", models.IntegerField()),
                ("queue_position", models.IntegerField()),
                ("skill_id", models.IntegerField()),
                ("finish_date", models.DateTimeField(default=None, null=True)),
                ("level_end_sp", models.IntegerField(default=None, null=True)),
                ("level_start_sp", models.IntegerField(default=None, null=True)),
                ("start_date", models.DateTimeField(default=None, null=True)),
                ("training_start_sp", models.IntegerField(default=None, null=True)),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "skill_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="Skillfilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                ("count_message_only", models.BooleanField(default=False)),
                (
                    "required_skill_lists",
                    models.ManyToManyField(
                        blank=True, to="corptools.skilllist"),
                ),
                (
                    "single_req_skill_lists",
                    models.ManyToManyField(
                        blank=True, related_name="single_req", to="corptools.skilllist"
                    ),
                ),
            ],
            options={
                "verbose_name": "Smart Filter: Skill list checks",
                "verbose_name_plural": "Smart Filter: Skill list checks",
            },
        ),
        migrations.CreateModel(
            name="Rolefilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                ("has_director", models.BooleanField(default=False)),
                ("has_accountant", models.BooleanField(default=False)),
                ("has_station_manager", models.BooleanField(default=False)),
                ("has_personnel_manager", models.BooleanField(default=False)),
                ("main_only", models.BooleanField(default=False)),
                (
                    "alliances_filter",
                    models.ManyToManyField(
                        blank=True,
                        related_name="audit_role_filters",
                        to="eveonline.eveallianceinfo",
                    ),
                ),
                (
                    "corps_filter",
                    models.ManyToManyField(
                        blank=True,
                        related_name="audit_role_filters",
                        to="eveonline.evecorporationinfo",
                    ),
                ),
            ],
            options={
                "verbose_name": "Smart Filter: Corporate Role checks",
                "verbose_name_plural": "Smart Filter: Corporate Role checks",
            },
        ),
        migrations.CreateModel(
            name="Poco",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("office_id", models.BigIntegerField()),
                ("alliance_tax_rate", models.FloatField(default=None, null=True)),
                ("corporation_tax_rate", models.FloatField(default=None, null=True)),
                (
                    "terrible_standing_tax_rate",
                    models.FloatField(default=None, null=True),
                ),
                ("bad_standing_tax_rate", models.FloatField(default=None, null=True)),
                (
                    "neutral_standing_tax_rate",
                    models.FloatField(default=None, null=True),
                ),
                ("good_standing_tax_rate", models.FloatField(
                    default=None, null=True)),
                (
                    "excellent_standing_tax_rate",
                    models.FloatField(default=None, null=True),
                ),
                ("reinforce_exit_end", models.IntegerField()),
                ("reinforce_exit_start", models.IntegerField()),
                (
                    "standing_level",
                    models.CharField(default=None, max_length=150, null=True),
                ),
                (
                    "allow_access_with_standings",
                    models.BooleanField(default=None, null=True),
                ),
                ("allow_alliance_access", models.BooleanField(
                    default=None, null=True)),
                ("system_id", models.IntegerField()),
                (
                    "name",
                    models.CharField(
                        blank=True, default=None, max_length=150, null=True
                    ),
                ),
                (
                    "corporation",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="ct_poco",
                        to="corptools.corporationaudit",
                    ),
                ),
                (
                    "planet",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="eve_sde.planet",
                    ),
                ),
                (
                    "system_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="eve_sde.solarsystem",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="OreTax",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("price", models.DecimalField(decimal_places=2, max_digits=20)),
                ("last_update", models.DateTimeField(auto_now=True)),
                (
                    "item",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="MapSystemPlanet",
            fields=[
                ("planet_id", models.IntegerField(
                    primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=255)),
                ("x", models.FloatField()),
                ("y", models.FloatField()),
                ("z", models.FloatField()),
                (
                    "eve_type",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.eveitemtype",
                    ),
                ),
                (
                    "system",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="planet",
                        to="corptools.mapsystem",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="MapSystemMoon",
            fields=[
                ("moon_id", models.IntegerField(primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=255)),
                ("x", models.FloatField()),
                ("y", models.FloatField()),
                ("z", models.FloatField()),
                (
                    "system",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="moon",
                        to="corptools.mapsystem",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="MapSystemGate",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "from_solar_system",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="from_system",
                        to="corptools.mapsystem",
                    ),
                ),
                (
                    "to_solar_system",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="to_system",
                        to="corptools.mapsystem",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="MapJumpBridge",
            fields=[
                (
                    "structure_id",
                    models.BigIntegerField(primary_key=True, serialize=False),
                ),
                ("updated", models.DateTimeField(auto_now=True)),
                ("manually_input", models.BooleanField(default=False)),
                (
                    "from_solar_system",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="bridge_from_system",
                        to="eve_sde.solarsystem",
                    ),
                ),
                (
                    "owner",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.evename",
                    ),
                ),
                (
                    "to_solar_system",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="bridge_to_system",
                        to="eve_sde.solarsystem",
                    ),
                ),
            ],
        ),
        migrations.AddField(
            model_name="mapconstellation",
            name="region",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="corptools.mapregion",
            ),
        ),
        migrations.CreateModel(
            name="MailRecipient",
            fields=[
                (
                    "recipient_id",
                    models.BigIntegerField(
                        primary_key=True, serialize=False, unique=True
                    ),
                ),
                (
                    "recipient_type",
                    models.CharField(
                        choices=[
                            ("alliance", "alliance"),
                            ("character", "character"),
                            ("corporation", "corporation"),
                            ("mailing_list", "mailing_list"),
                        ],
                        max_length=15,
                    ),
                ),
                (
                    "recipient_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.evename",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="MailMessage",
            fields=[
                (
                    "id_key",
                    models.BigIntegerField(
                        primary_key=True, serialize=False, unique=True
                    ),
                ),
                ("mail_id", models.IntegerField(default=None, null=True)),
                ("from_id", models.IntegerField(default=None, null=True)),
                ("is_read", models.BooleanField(default=False, null=True)),
                ("timestamp", models.DateTimeField(default=None, null=True)),
                ("subject", models.CharField(default=None, max_length=255, null=True)),
                ("body", models.CharField(default=None, max_length=12000, null=True)),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "from_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.evename",
                    ),
                ),
                ("labels", models.ManyToManyField(to="corptools.maillabel")),
                ("recipients", models.ManyToManyField(
                    to="corptools.mailrecipient")),
            ],
        ),
        migrations.CreateModel(
            name="JumpCloneFilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                (
                    "evelocation",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Limit filter to specific Structures",
                        to="corptools.evelocation",
                    ),
                ),
            ],
            options={
                "verbose_name": "Smart Filter: Jump Clone",
                "verbose_name_plural": "Smart Filter: Jump Clone",
            },
        ),
        migrations.CreateModel(
            name="JumpClone",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("jump_clone_id", models.IntegerField(default=None, null=True)),
                ("location_id", models.BigIntegerField(default=None, null=True)),
                (
                    "location_type",
                    models.CharField(
                        choices=[("station", "station"),
                                 ("structure", "structure")],
                        default=None,
                        max_length=9,
                        null=True,
                    ),
                ),
                ("name", models.CharField(default=None, max_length=255, null=True)),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "location_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.evelocation",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="InvTypeMaterials",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("qty", models.IntegerField()),
                ("type_id", models.IntegerField()),
                ("material_type_id", models.IntegerField()),
                (
                    "eve_type",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.eveitemtype",
                    ),
                ),
                (
                    "met_type",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="met_type",
                        to="corptools.eveitemtype",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="Implant",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "clone",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.jumpclone",
                    ),
                ),
                (
                    "type_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="HomeStationFilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                (
                    "evelocation",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Limit filter to specific Structures",
                        to="corptools.evelocation",
                    ),
                ),
            ],
            options={
                "verbose_name": "Smart Filter: Home Station (Death Clone)",
                "verbose_name_plural": "Smart Filter: Home Station (Death Clone)",
            },
        ),
        migrations.CreateModel(
            name="EveItemDogmaAttribute",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("attribute_id", models.BigIntegerField(default=None, null=True)),
                ("value", models.FloatField(default=None, null=True)),
                (
                    "eve_type",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.eveitemtype",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="CurrentShipFilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                ("count_message_only", models.BooleanField(default=False)),
                (
                    "constellations",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Limit filter to specific constellations",
                        to="eve_sde.constellation",
                    ),
                ),
                (
                    "groups",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Filter on Ship Groups.",
                        to="eve_sde.itemgroup",
                    ),
                ),
                (
                    "regions",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Limit filter to specific regions",
                        to="eve_sde.region",
                    ),
                ),
                (
                    "systems",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Limit filter to specific systems",
                        to="eve_sde.solarsystem",
                    ),
                ),
                (
                    "types",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Filter on Ship Types.",
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
            options={
                "verbose_name": "Smart Filter: The Current Ship being Flown",
                "verbose_name_plural": "Smart Filter: The Current Ship being Flown",
            },
        ),
        migrations.CreateModel(
            name="CorptoolsConfiguration",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "aggregate_lookback",
                    models.IntegerField(
                        default=90,
                        help_text="Days to look back in aggregated views, like the mining ledger graphs.",
                    ),
                ),
                (
                    "disable_verification_assets",
                    models.BooleanField(
                        default=False,
                        help_text="Allow ESI to provide data that does not match the ESI Assets Spec",
                    ),
                ),
                (
                    "disable_verification_notifications",
                    models.BooleanField(
                        default=False,
                        help_text="Allow ESI to provide data that does not match the ESI Notification Spec",
                    ),
                ),
                (
                    "disable_update_pub_data",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Pulic History Data",
                    ),
                ),
                (
                    "disable_update_skills",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character SKill Data",
                    ),
                ),
                (
                    "disable_update_clones",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Clone Data",
                    ),
                ),
                (
                    "disable_update_contacts",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Contact Data",
                    ),
                ),
                (
                    "disable_update_contracts",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Contracts Data",
                    ),
                ),
                (
                    "disable_update_assets",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Asset Data",
                    ),
                ),
                (
                    "disable_update_wallet",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Wallet Data",
                    ),
                ),
                (
                    "disable_update_notif",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Notification Data",
                    ),
                ),
                (
                    "disable_update_roles",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Roles Data",
                    ),
                ),
                (
                    "disable_update_mails",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Mail Data",
                    ),
                ),
                (
                    "disable_update_location",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Location Data",
                    ),
                ),
                (
                    "disable_update_loyaltypoints",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Loyalty Point Data",
                    ),
                ),
                (
                    "disable_update_mining",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character Mining Data",
                    ),
                ),
                (
                    "disable_update_indy",
                    models.BooleanField(
                        blank=True,
                        default=False,
                        help_text="Temporarily disable the ESI pulls for Character industry Job Data",
                    ),
                ),
                (
                    "holding_corps",
                    models.ManyToManyField(
                        blank=True, to="eveonline.evecorporationinfo"
                    ),
                ),
            ],
            options={
                "permissions": (
                    (
                        "holding_corp_structures",
                        "Can access configured holding corp structure data.",
                    ),
                    (
                        "holding_corp_wallets",
                        "Can access configured holding corp wallet data.",
                    ),
                    (
                        "holding_corp_assets",
                        "Can access configured holding corp asset data.",
                    ),
                ),
                "default_permissions": [],
            },
        ),
        migrations.CreateModel(
            name="CorporationMarketOrder",
            fields=[
                ("order_id", models.BigIntegerField(
                    primary_key=True, serialize=False)),
                ("duration", models.IntegerField()),
                (
                    "escrow",
                    models.DecimalField(
                        decimal_places=2, default=None, max_digits=20, null=True
                    ),
                ),
                ("is_buy_order", models.BooleanField(default=None, null=True)),
                ("issued", models.DateTimeField()),
                ("location_id", models.BigIntegerField()),
                ("min_volume", models.IntegerField(default=None, null=True)),
                (
                    "price",
                    models.DecimalField(
                        decimal_places=2, default=None, max_digits=20, null=True
                    ),
                ),
                (
                    "order_range",
                    models.CharField(
                        choices=[
                            ("1", "1"),
                            ("10", "10"),
                            ("2", "2"),
                            ("20", "20"),
                            ("3", "3"),
                            ("30", "30"),
                            ("4", "4"),
                            ("40", "40"),
                            ("5", "5"),
                            ("region", "region"),
                            ("solarsystem", "solarsystem"),
                            ("station", "station"),
                        ],
                        max_length=30,
                    ),
                ),
                ("region_id", models.IntegerField()),
                ("type_id", models.IntegerField()),
                ("volume_remain", models.IntegerField()),
                ("volume_total", models.IntegerField()),
                (
                    "state",
                    models.CharField(
                        choices=[
                            ("cancelled", "cancelled"),
                            ("expired", "expired"),
                            ("active", "active"),
                        ],
                        max_length=30,
                    ),
                ),
                ("issued_by", models.IntegerField()),
                (
                    "location_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.evelocation",
                    ),
                ),
                (
                    "region_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="eve_sde.region",
                    ),
                ),
                (
                    "type_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="eve_sde.itemtype",
                    ),
                ),
                (
                    "wallet_division",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.corporationwalletdivision",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="CorporationIndustryJob",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("activity_id", models.IntegerField()),
                ("blueprint_id", models.BigIntegerField()),
                ("blueprint_location_id", models.BigIntegerField()),
                ("blueprint_type_id", models.BigIntegerField()),
                (
                    "completed_character_id",
                    models.BigIntegerField(
                        blank=True, default=None, null=True),
                ),
                (
                    "completed_date",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "cost",
                    models.DecimalField(
                        blank=True,
                        decimal_places=2,
                        default=None,
                        max_digits=20,
                        null=True,
                    ),
                ),
                ("duration", models.IntegerField()),
                ("end_date", models.DateTimeField()),
                ("facility_id", models.BigIntegerField()),
                ("installer_id", models.IntegerField()),
                ("job_id", models.IntegerField()),
                (
                    "licensed_runs",
                    models.IntegerField(blank=True, default=None, null=True),
                ),
                ("location_id", models.BigIntegerField()),
                ("output_location_id", models.BigIntegerField()),
                (
                    "pause_date",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                ("probability", models.FloatField(
                    blank=True, default=None, null=True)),
                ("product_type_id", models.IntegerField()),
                ("runs", models.IntegerField()),
                ("start_date", models.DateTimeField()),
                ("status", models.CharField(max_length=15)),
                (
                    "successful_runs",
                    models.IntegerField(blank=True, default=None, null=True),
                ),
                (
                    "blueprint_type_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="corp_blueprint_type",
                        to="eve_sde.itemtype",
                    ),
                ),
                (
                    "corporation",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.corporationaudit",
                    ),
                ),
                (
                    "product_type_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="corp_product_type",
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="CorporationHistory",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("corporation_id", models.IntegerField()),
                ("is_deleted", models.BooleanField(default=None, null=True)),
                ("record_id", models.IntegerField()),
                ("start_date", models.DateTimeField()),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "corporation_name",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.evename",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="CorporationContactLabel",
            fields=[
                ("id", models.BigIntegerField(primary_key=True, serialize=False)),
                ("label_id", models.BigIntegerField()),
                ("label_name", models.CharField(max_length=255)),
                (
                    "corporation",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.corporationaudit",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="CorporationContact",
            fields=[
                ("id", models.BigIntegerField(primary_key=True, serialize=False)),
                ("contact_id", models.BigIntegerField()),
                ("contact_type", models.CharField(max_length=255)),
                ("standing", models.DecimalField(decimal_places=2, max_digits=4)),
                ("watched", models.BooleanField(default=False)),
                (
                    "contact_name",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.evename",
                    ),
                ),
                (
                    "corporation",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.corporationaudit",
                    ),
                ),
                (
                    "labels",
                    models.ManyToManyField(
                        to="corptools.corporationcontactlabel"),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="CorporateContract",
            fields=[
                (
                    "id",
                    models.CharField(
                        max_length=50, primary_key=True, serialize=False),
                ),
                ("contract_id", models.BigIntegerField()),
                ("acceptor_id", models.IntegerField()),
                ("assignee_id", models.IntegerField()),
                ("issuer_id", models.IntegerField()),
                ("issuer_corporation_id", models.IntegerField()),
                (
                    "collateral",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=20, null=True
                    ),
                ),
                (
                    "buyout",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=20, null=True
                    ),
                ),
                (
                    "price",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=20, null=True
                    ),
                ),
                (
                    "reward",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=20, null=True
                    ),
                ),
                (
                    "volume",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=20, null=True
                    ),
                ),
                ("days_to_complete", models.IntegerField(blank=True, null=True)),
                ("start_location_id", models.BigIntegerField(blank=True, null=True)),
                ("end_location_id", models.BigIntegerField(blank=True, null=True)),
                ("for_corporation", models.BooleanField()),
                ("date_accepted", models.DateTimeField(blank=True, null=True)),
                ("date_completed", models.DateTimeField(blank=True, null=True)),
                ("date_expired", models.DateTimeField()),
                ("date_issued", models.DateTimeField()),
                ("status", models.CharField(max_length=25)),
                ("contract_type", models.CharField(max_length=20)),
                ("availability", models.CharField(max_length=15)),
                ("title", models.CharField(max_length=256)),
                (
                    "acceptor_name",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="corporationcontractacceptor",
                        to="corptools.evename",
                    ),
                ),
                (
                    "assignee_name",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="corporationcontractassignee",
                        to="corptools.evename",
                    ),
                ),
                (
                    "corporation",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.corporationaudit",
                    ),
                ),
                (
                    "end_location_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="corporationcontractto",
                        to="corptools.evelocation",
                    ),
                ),
                (
                    "issuer_corporation_name",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="corporationcontractissuercorporation",
                        to="corptools.evename",
                    ),
                ),
                (
                    "issuer_name",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="corporationcontractissuer",
                        to="corptools.evename",
                    ),
                ),
                (
                    "start_location_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="corporationcontractfrom",
                        to="corptools.evelocation",
                    ),
                ),
            ],
            options={
                "unique_together": {("corporation", "contract_id")},
            },
        ),
        migrations.AddField(
            model_name="corpasset",
            name="corporation",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="corptools.corporationaudit",
            ),
        ),
        migrations.AddField(
            model_name="corpasset",
            name="location_name",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="corptools.evelocation",
            ),
        ),
        migrations.AddField(
            model_name="corpasset",
            name="type_name",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="eve_sde.itemtype",
            ),
        ),
        migrations.CreateModel(
            name="ContractItem",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("is_included", models.BooleanField()),
                ("is_singleton", models.BooleanField()),
                ("quantity", models.IntegerField()),
                ("raw_quantity", models.IntegerField(blank=True, null=True)),
                ("record_id", models.BigIntegerField()),
                (
                    "contract",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.contract",
                    ),
                ),
                (
                    "type_name",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
        ),
        migrations.AddField(
            model_name="contract",
            name="acceptor_name",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contractacceptor",
                to="corptools.evename",
            ),
        ),
        migrations.AddField(
            model_name="contract",
            name="assignee_name",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contractassignee",
                to="corptools.evename",
            ),
        ),
        migrations.AddField(
            model_name="contract",
            name="character",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="corptools.characteraudit",
            ),
        ),
        migrations.AddField(
            model_name="contract",
            name="end_location_name",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="contractto",
                to="corptools.evelocation",
            ),
        ),
        migrations.AddField(
            model_name="contract",
            name="issuer_corporation_name",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contractissuercorporation",
                to="corptools.evename",
            ),
        ),
        migrations.AddField(
            model_name="contract",
            name="issuer_name",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contractissuer",
                to="corptools.evename",
            ),
        ),
        migrations.AddField(
            model_name="contract",
            name="start_location_name",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="contractfrom",
                to="corptools.evelocation",
            ),
        ),
        migrations.CreateModel(
            name="Clone",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_clone_jump_date", models.DateTimeField(
                    default=None, null=True)),
                (
                    "last_station_change_date",
                    models.DateTimeField(default=None, null=True),
                ),
                ("location_id", models.BigIntegerField()),
                (
                    "location_type",
                    models.CharField(
                        choices=[("station", "station"),
                                 ("structure", "structure")],
                        max_length=9,
                    ),
                ),
                (
                    "character",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "location_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.evelocation",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="CharacterWalletJournalEntry",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "amount",
                    models.DecimalField(
                        decimal_places=2, default=None, max_digits=20, null=True
                    ),
                ),
                (
                    "balance",
                    models.DecimalField(
                        decimal_places=2, default=None, max_digits=20, null=True
                    ),
                ),
                ("context_id", models.BigIntegerField(default=None, null=True)),
                (
                    "context_id_type",
                    models.CharField(
                        choices=[
                            ("structure_id", "structure_id"),
                            ("station_id", "station_id"),
                            ("market_transaction_id", "market_transaction_id"),
                            ("character_id", "character_id"),
                            ("corporation_id", "corporation_id"),
                            ("alliance_id", "alliance_id"),
                            ("eve_system", "eve_system"),
                            ("industry_job_id", "industry_job_id"),
                            ("contract_id", "contract_id"),
                            ("planet_id", "planet_id"),
                            ("system_id", "system_id"),
                            ("type_id", "type_id"),
                        ],
                        default=None,
                        max_length=30,
                        null=True,
                    ),
                ),
                ("date", models.DateTimeField()),
                ("description", models.CharField(max_length=500)),
                ("first_party_id", models.IntegerField(default=None, null=True)),
                ("entry_id", models.BigIntegerField()),
                ("reason", models.CharField(default=None, max_length=500, null=True)),
                ("ref_type", models.CharField(max_length=72)),
                ("second_party_id", models.IntegerField(default=None, null=True)),
                (
                    "tax",
                    models.DecimalField(
                        decimal_places=2, default=None, max_digits=20, null=True
                    ),
                ),
                ("tax_receiver_id", models.IntegerField(default=None, null=True)),
                ("processed", models.BooleanField(default=False)),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "first_party_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="char_first_party",
                        to="corptools.evename",
                    ),
                ),
                (
                    "second_party_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="char_second_party",
                        to="corptools.evename",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="CharacterRoles",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("director", models.BooleanField(default=False)),
                ("accountant", models.BooleanField(default=False)),
                ("station_manager", models.BooleanField(default=False)),
                ("personnel_manager", models.BooleanField(default=False)),
                (
                    "character",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                ("titles", models.ManyToManyField(to="corptools.charactertitle")),
            ],
        ),
        migrations.CreateModel(
            name="CharacterMiningLedger",
            fields=[
                (
                    "id",
                    models.CharField(
                        max_length=50, primary_key=True, serialize=False),
                ),
                ("date", models.DateField()),
                ("quantity", models.IntegerField()),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "system",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eve_sde.solarsystem",
                    ),
                ),
                (
                    "type_name",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="CharacterMarketOrder",
            fields=[
                ("order_id", models.BigIntegerField(
                    primary_key=True, serialize=False)),
                ("duration", models.IntegerField()),
                (
                    "escrow",
                    models.DecimalField(
                        decimal_places=2, default=None, max_digits=20, null=True
                    ),
                ),
                ("is_buy_order", models.BooleanField(default=None, null=True)),
                ("issued", models.DateTimeField()),
                ("location_id", models.BigIntegerField()),
                ("min_volume", models.IntegerField(default=None, null=True)),
                (
                    "price",
                    models.DecimalField(
                        decimal_places=2, default=None, max_digits=20, null=True
                    ),
                ),
                (
                    "order_range",
                    models.CharField(
                        choices=[
                            ("1", "1"),
                            ("10", "10"),
                            ("2", "2"),
                            ("20", "20"),
                            ("3", "3"),
                            ("30", "30"),
                            ("4", "4"),
                            ("40", "40"),
                            ("5", "5"),
                            ("region", "region"),
                            ("solarsystem", "solarsystem"),
                            ("station", "station"),
                        ],
                        max_length=30,
                    ),
                ),
                ("region_id", models.IntegerField()),
                ("type_id", models.IntegerField()),
                ("volume_remain", models.IntegerField()),
                ("volume_total", models.IntegerField()),
                (
                    "state",
                    models.CharField(
                        choices=[
                            ("cancelled", "cancelled"),
                            ("expired", "expired"),
                            ("active", "active"),
                        ],
                        max_length=30,
                    ),
                ),
                ("is_corporation", models.BooleanField()),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "location_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="corptools.evelocation",
                    ),
                ),
                (
                    "region_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="eve_sde.region",
                    ),
                ),
                (
                    "type_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="CharacterLocation",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "current_ship_unique",
                    models.BigIntegerField(
                        blank=True, default=None, null=True),
                ),
                (
                    "current_ship_name",
                    models.TextField(
                        blank=True, default=None, max_length=150, null=True
                    ),
                ),
                (
                    "character",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="location",
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "current_location",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.evelocation",
                    ),
                ),
                (
                    "current_ship",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="CharacterIndustryJob",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("activity_id", models.IntegerField()),
                ("blueprint_id", models.BigIntegerField()),
                ("blueprint_location_id", models.BigIntegerField()),
                ("blueprint_type_id", models.BigIntegerField()),
                (
                    "completed_character_id",
                    models.BigIntegerField(
                        blank=True, default=None, null=True),
                ),
                (
                    "completed_date",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                (
                    "cost",
                    models.DecimalField(
                        blank=True,
                        decimal_places=2,
                        default=None,
                        max_digits=20,
                        null=True,
                    ),
                ),
                ("duration", models.IntegerField()),
                ("end_date", models.DateTimeField()),
                ("facility_id", models.BigIntegerField()),
                ("installer_id", models.IntegerField()),
                ("job_id", models.IntegerField()),
                (
                    "licensed_runs",
                    models.IntegerField(blank=True, default=None, null=True),
                ),
                ("output_location_id", models.BigIntegerField()),
                (
                    "pause_date",
                    models.DateTimeField(blank=True, default=None, null=True),
                ),
                ("probability", models.FloatField(
                    blank=True, default=None, null=True)),
                ("product_type_id", models.IntegerField()),
                ("runs", models.IntegerField()),
                ("start_date", models.DateTimeField()),
                ("station_id", models.BigIntegerField()),
                ("status", models.CharField(max_length=15)),
                (
                    "successful_runs",
                    models.IntegerField(blank=True, default=None, null=True),
                ),
                (
                    "blueprint_type_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="blueprint_type",
                        to="eve_sde.itemtype",
                    ),
                ),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "product_type_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="product_type",
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="CharacterContactLabel",
            fields=[
                ("id", models.BigIntegerField(primary_key=True, serialize=False)),
                ("label_id", models.BigIntegerField()),
                ("label_name", models.CharField(max_length=255)),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="CharacterContact",
            fields=[
                ("id", models.BigIntegerField(primary_key=True, serialize=False)),
                ("contact_id", models.BigIntegerField()),
                ("contact_type", models.CharField(max_length=255)),
                ("standing", models.DecimalField(decimal_places=2, max_digits=4)),
                ("blocked", models.BooleanField(default=False)),
                ("watched", models.BooleanField(default=False)),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "contact_name",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.evename",
                    ),
                ),
                (
                    "labels",
                    models.ManyToManyField(
                        to="corptools.charactercontactlabel"),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="CharacterBountyStat",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("qty", models.IntegerField()),
                (
                    "event",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="stats",
                        to="corptools.characterbountyevent",
                    ),
                ),
                (
                    "type_name",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
        ),
        migrations.AddField(
            model_name="characterbountyevent",
            name="entry",
            field=models.OneToOneField(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="msg",
                to="corptools.characterwalletjournalentry",
            ),
        ),
        migrations.AddField(
            model_name="characterasset",
            name="character",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="corptools.characteraudit",
            ),
        ),
        migrations.AddField(
            model_name="characterasset",
            name="location_name",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="corptools.evelocation",
            ),
        ),
        migrations.AddField(
            model_name="characterasset",
            name="type_name",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="eve_sde.itemtype",
            ),
        ),
        migrations.CreateModel(
            name="AssetsFilter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=500)),
                ("description", models.CharField(max_length=500)),
                ("count_message_only", models.BooleanField(default=False)),
                (
                    "reversed_logic",
                    models.BooleanField(
                        default=False,
                        help_text="Negate the value of the filter, i.e. check for absence of assets",
                    ),
                ),
                (
                    "categories",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Filter on Asset Categories.",
                        to="eve_sde.itemcategory",
                    ),
                ),
                (
                    "constellations",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Limit filter to specific constellations",
                        to="eve_sde.constellation",
                    ),
                ),
                (
                    "groups",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Filter on Asset Groups.",
                        to="eve_sde.itemgroup",
                    ),
                ),
                (
                    "regions",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Limit filter to specific regions",
                        to="eve_sde.region",
                    ),
                ),
                (
                    "systems",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Limit filter to specific systems",
                        to="eve_sde.solarsystem",
                    ),
                ),
                (
                    "types",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Filter on Asset Types.",
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
            options={
                "verbose_name": "Smart Filter: Assets in Locations",
                "verbose_name_plural": "Smart Filter: Assets in Locations",
            },
        ),
        migrations.CreateModel(
            name="Skill",
            fields=[
                ("id", models.BigAutoField(primary_key=True, serialize=False)),
                ("skill_id", models.IntegerField()),
                ("active_skill_level", models.IntegerField()),
                ("skillpoints_in_skill", models.BigIntegerField()),
                ("trained_skill_level", models.IntegerField()),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "skill_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
            options={
                "unique_together": {("character", "skill_id")},
            },
        ),
        migrations.CreateModel(
            name="Notification",
            fields=[
                ("id", models.BigAutoField(primary_key=True, serialize=False)),
                ("notification_id", models.BigIntegerField()),
                ("sender_id", models.IntegerField()),
                (
                    "sender_type",
                    models.CharField(
                        choices=[
                            ("character", "character"),
                            ("corporation", "corporation"),
                            ("alliance", "alliance"),
                            ("faction", "faction"),
                            ("other", "other"),
                        ],
                        max_length=15,
                    ),
                ),
                ("timestamp", models.DateTimeField()),
                ("notification_type", models.CharField(max_length=50)),
                ("is_read", models.BooleanField(default=None, null=True)),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                    ),
                ),
                (
                    "notification_text",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.notificationtext",
                    ),
                ),
            ],
            options={
                "indexes": [
                    models.Index(
                        fields=["timestamp"], name="corptools_n_timesta_ca02fe_idx"
                    ),
                    models.Index(
                        fields=["notification_type"],
                        name="corptools_n_notific_8ff99b_idx",
                    ),
                ],
            },
        ),
        migrations.CreateModel(
            name="LoyaltyPoint",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("amount", models.IntegerField(verbose_name="LP")),
                (
                    "character",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.characteraudit",
                        verbose_name="Character",
                    ),
                ),
                (
                    "corporation",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.evename",
                        verbose_name="NPC Corporation",
                    ),
                ),
            ],
            options={
                "verbose_name": "Loyalty Point",
                "unique_together": {("character", "corporation")},
            },
        ),
        migrations.CreateModel(
            name="CorporationWalletJournalEntry",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "amount",
                    models.DecimalField(
                        decimal_places=2, default=None, max_digits=20, null=True
                    ),
                ),
                (
                    "balance",
                    models.DecimalField(
                        decimal_places=2, default=None, max_digits=20, null=True
                    ),
                ),
                ("context_id", models.BigIntegerField(default=None, null=True)),
                (
                    "context_id_type",
                    models.CharField(
                        choices=[
                            ("structure_id", "structure_id"),
                            ("station_id", "station_id"),
                            ("market_transaction_id", "market_transaction_id"),
                            ("character_id", "character_id"),
                            ("corporation_id", "corporation_id"),
                            ("alliance_id", "alliance_id"),
                            ("eve_system", "eve_system"),
                            ("industry_job_id", "industry_job_id"),
                            ("contract_id", "contract_id"),
                            ("planet_id", "planet_id"),
                            ("system_id", "system_id"),
                            ("type_id", "type_id"),
                        ],
                        default=None,
                        max_length=30,
                        null=True,
                    ),
                ),
                ("date", models.DateTimeField()),
                ("description", models.CharField(max_length=500)),
                ("first_party_id", models.IntegerField(default=None, null=True)),
                ("entry_id", models.BigIntegerField()),
                ("reason", models.CharField(default=None, max_length=500, null=True)),
                ("ref_type", models.CharField(max_length=72)),
                ("second_party_id", models.IntegerField(default=None, null=True)),
                (
                    "tax",
                    models.DecimalField(
                        decimal_places=2, default=None, max_digits=20, null=True
                    ),
                ),
                ("tax_receiver_id", models.IntegerField(default=None, null=True)),
                ("processed", models.BooleanField(default=False)),
                (
                    "division",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.corporationwalletdivision",
                    ),
                ),
                (
                    "first_party_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="corp_first_party",
                        to="corptools.evename",
                    ),
                ),
                (
                    "second_party_name",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="corp_second_party",
                        to="corptools.evename",
                    ),
                ),
            ],
            options={
                "abstract": False,
                "indexes": [
                    models.Index(fields=["date"],
                                 name="corptools_c_date_ca15ac_idx"),
                    models.Index(
                        fields=["entry_id"], name="corptools_c_entry_i_09f70e_idx"
                    ),
                    models.Index(
                        fields=["ref_type"], name="corptools_c_ref_typ_326ddd_idx"
                    ),
                ],
            },
        ),
        migrations.CreateModel(
            name="CorporateContractItem",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("is_included", models.BooleanField()),
                ("is_singleton", models.BooleanField()),
                ("quantity", models.IntegerField()),
                ("raw_quantity", models.IntegerField(blank=True, null=True)),
                ("record_id", models.BigIntegerField()),
                (
                    "contract",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="corptools.corporatecontract",
                    ),
                ),
                (
                    "type_name",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="eve_sde.itemtype",
                    ),
                ),
            ],
            options={
                "unique_together": {("record_id", "contract")},
            },
        ),
        migrations.AddIndex(
            model_name="corpasset",
            index=models.Index(
                fields=["location_id"], name="corptools_c_locatio_a86faf_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="corpasset",
            index=models.Index(
                fields=["item_id"], name="corptools_c_item_id_41066b_idx"
            ),
        ),
        migrations.AlterUniqueTogether(
            name="contractitem",
            unique_together={("record_id", "contract")},
        ),
        migrations.AlterUniqueTogether(
            name="contract",
            unique_together={("character", "contract_id")},
        ),
        migrations.AddIndex(
            model_name="characterwalletjournalentry",
            index=models.Index(
                fields=["date"], name="corptools_c_date_aebcea_idx"),
        ),
        migrations.AddIndex(
            model_name="characterwalletjournalentry",
            index=models.Index(
                fields=["entry_id"], name="corptools_c_entry_i_d9e191_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="characterwalletjournalentry",
            index=models.Index(
                fields=["ref_type"], name="corptools_c_ref_typ_fe0ec9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="characterasset",
            index=models.Index(
                fields=["location_id"], name="corptools_c_locatio_b58222_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="characterasset",
            index=models.Index(
                fields=["item_id"], name="corptools_c_item_id_1800a8_idx"
            ),
        ),
    ]
